@@ -2,6 +2,7 @@ from maggma.api.resource import ReadOnlyResource
 from emmet.core.dois import DOIDoc
 from emmet.api.core.global_header import GlobalHeaderProcessor
 from maggma.api.query_operator import PaginationQuery, SparseFieldsQuery
+from emmet.api.core.settings import MAPISettings
 
 
 def dois_resource(dois_store):
@@ -16,6 +17,7 @@ def dois_resource(dois_store):
         tags=["DOIs"],
         enable_default_search=False,
         disable_validation=True,
+        timeout=MAPISettings().TIMEOUT,
     )
 
     return resource
